@@ -1,3 +1,10 @@
+"""
+lava.celery.views
+=================
+
+Django view definitions provided by lava-celery
+"""
+
 from django.shortcuts import render_to_response
 from django.template import RequestContext
 from django.conf import settings
